==> igniteui-react-charts-16.6.4.tgz: package/ES2015/PolarSplineAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, markType } from "igniteui-react-core/ES2015/type";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES2015/Path";
import { PathGeometry } from "igniteui-react-core/ES2015/PathGeometry";
import { Extensions } from "igniteui-react-core/ES2015/Extensions";
import { Numeric } from "igniteui-react-core/ES2015/Numeric";
import { Color } from "igniteui-react-core/ES2015/Color";
export class PolarSplineAreaSeries extends PolarLineSeriesBase {
    constructor() {
        super();
        this.ab = PolarSplineAreaSeries.$;
    }
    bf() {
        return new PolarSplineAreaSeriesView(this);
    }
    il(a) {
        super.il(a);
        this.o4 = a;
    }
    o2(a) {
        let b = a;
        b.c0();
    }
    o3(a, b) {
        this.o2(b);
        if (a.m.count < 1) {
            return;
        }
        let c = b;
        c.c3._opacity = this.d2;
        c.c1(a.m, this.o5);
    }
    get_oz() {
        return true;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case PolarSplineAreaSeries.$$p[0]:
                this.i4(false);
                break;
        }
    }
}
PolarSplineAreaSeries.$t = markType(PolarSplineAreaSeries, 'PolarSplineAreaSeries', PolarLineSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, PolarSplineAreaSeries, 'raisePropertyChanged', ['Stiffness:o5:o7', [1, 0.5]]);
export class PolarSplineAreaSeriesView extends PolarLineSeriesBaseView {
    constructor(a) {
        super(a);
        this.cz = null;
        this.c4 = ((() => {
            let $ret = new Path();
            $ret.aj = new PathGeometry();
            return $ret;
        })());
        this.c2 = ((() => {
            let $ret = new Path();
            $ret.aj = new PathGeometry();
            return $ret;
        })());
        this.cz = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    get c3() {
        return this.c2;
    }
    c0() {
        Extensions.e(this.c2.aj);
        Extensions.e(this.c4.aj);
        this.an();
    }
    c1(a, b) {
        this.c4.aj.b = Numeric.h(a.count + 1, (c) => c < a.count ? a._inner[c].x : a._inner[c - a.count].x, (c) => c < a.count ? a._inner[c].y : a._inner[c - a.count].y, b);
        this.c2.aj.b = Numeric.h(a.count + 1, (c) => c < a.count ? a._inner[c].x : a._inner[c - a.count].x, (c) => c < a.count ? a._inner[c].y : a._inner[c - a.count].y, b);
        this.an();
    }
    a8() {
        super.a8();
        this.c2._fill = this.e.ku;
        this.c2._opacity = this.e.d2;
        this.c4._stroke = this.e.kv;
        this.c4.ac = this.e.eu;
        this.c4.ai = this.e.k2;
        this.c4.ad = this.e.k3;
    }
    a9() {
        super.a9();
        let a = this.bl();
        this.c2._fill = a;
        this.c2._opacity = 1;
        this.c4._stroke = a;
        this.c4.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            a.s(this.c2);
            a.s(this.c4);
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.c4, "polarShape", ["Main"]);
        this.e.a2.exportPathData(a, this.c2, "fillShape", ["Fill"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 5;
        this.e.es = 5;
        this.e.et = 5;
    }
}
PolarSplineAreaSeriesView.$t = markType(PolarSplineAreaSeriesView, 'PolarSplineAreaSeriesView', PolarLineSeriesBaseView.$);

==> igniteui-react-charts-16.6.8.tgz: package/ES2015/PolarSplineAreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, markType } from "igniteui-react-core/ES2015/type";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Path } from "igniteui-react-core/ES2015/Path";
import { PathGeometry } from "igniteui-react-core/ES2015/PathGeometry";
import { Extensions } from "igniteui-react-core/ES2015/Extensions";
import { Numeric } from "igniteui-react-core/ES2015/Numeric";
import { Color } from "igniteui-react-core/ES2015/Color";
/**
 * @hidden
 */
export class PolarSplineAreaSeries extends PolarLineSeriesBase {
    constructor() {
        super();
        this.ab = PolarSplineAreaSeries.$;
    }
    bf() {
        return new PolarSplineAreaSeriesView(this);
    }
    im(a) {
        super.im(a);
        this.o6 = a;
    }
    o4(a) {
        let b = a;
        b.c0();
    }
    o5(a, b) {
        this.o4(b);
        if (a.m.count < 1) {
            return;
        }
        let c = b;
        c.c3._opacity = this.d3;
        c.c1(a.m, this.o7);
    }
    get_o1() {
        return true;
    }
    is(a, b, c, d) {
        super.is(a, b, c, d);
        switch (b) {
            case PolarSplineAreaSeries.$$p[0]:
                this.i6(false);
                break;
        }
    }
}
PolarSplineAreaSeries.$t = markType(PolarSplineAreaSeries, 'PolarSplineAreaSeries', PolarLineSeriesBase.$);
Type.dep(DependencyProperty, PropertyMetadata, PolarSplineAreaSeries, 'raisePropertyChanged', ['Stiffness:o7:o9', [1, 0.5]]);
/**
 * @hidden
 */
export class PolarSplineAreaSeriesView extends PolarLineSeriesBaseView {
    constructor(a) {
        super(a);
        this.cz = null;
        this.c4 = ((() => {
            let $ret = new Path();
            $ret.aj = new PathGeometry();
            return $ret;
        })());
        this.c2 = ((() => {
            let $ret = new Path();
            $ret.aj = new PathGeometry();
            return $ret;
        })());
        this.cz = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    get c3() {
        return this.c2;
    }
    c0() {
        Extensions.e(this.c2.aj);
        Extensions.e(this.c4.aj);
        this.an();
    }
    c1(a, b) {
        this.c4.aj.b = Numeric.h(a.count + 1, (c) => c < a.count ? a._inner[c].x : a._inner[c - a.count].x, (c) => c < a.count ? a._inner[c].y : a._inner[c - a.count].y, b);
        this.c2.aj.b = Numeric.h(a.count + 1, (c) => c < a.count ? a._inner[c].x : a._inner[c - a.count].x, (c) => c < a.count ? a._inner[c].y : a._inner[c - a.count].y, b);
        this.an();
    }
    a8() {
        super.a8();
        this.c2._fill = this.e.kw;
        this.c2._opacity = this.e.d3;
        this.c4._stroke = this.e.kx;
        this.c4.ac = this.e.ev;
        this.c4.ai = this.e.k4;
        this.c4.ad = this.e.k5;
    }
    a9() {
        super.a9();
        let a = this.bl();
        this.c2._fill = a;
        this.c2._opacity = 1;
        this.c4._stroke = a;
        this.c4.ac = this.e.ev + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (a.d) {
            a.s(this.c2);
            a.s(this.c4);
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.c4, "polarShape", ["Main"]);
        this.e.a2.exportPathData(a, this.c2, "fillShape", ["Fill"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k3 = a;
        this.e.es = 5;
        this.e.et = 5;
        this.e.eu = 5;
    }
}
PolarSplineAreaSeriesView.$t = markType(PolarSplineAreaSeriesView, 'PolarSplineAreaSeriesView', PolarLineSeriesBaseView.$);
